========
cyminmax
========


.. image:: https://img.shields.io/pypi/v/cyminmax.svg
        :target: https://pypi.python.org/pypi/cyminmax
        :alt: PyPI

.. image:: https://anaconda.org/conda-forge/cyminmax/badges/version.svg
        :target: https://anaconda.org/conda-forge/cyminmax
        :alt: conda-forge

.. image:: https://img.shields.io/travis/jakirkham/cyminmax/master.svg
        :target: https://travis-ci.org/jakirkham/cyminmax
        :alt: Travis CI

.. image:: https://ci.appveyor.com/api/projects/status/github/jakirkham/cyminmax?svg=true&branch=master
        :target: https://ci.appveyor.com/project/jakirkham/cyminmax
        :alt: AppVeyor

.. image:: https://readthedocs.org/projects/cyminmax/badge/?version=latest
        :target: https://cyminmax.readthedocs.io/en/latest/?badge=latest
        :alt: Read the Docs

.. image:: https://coveralls.io/repos/github/jakirkham/cyminmax/badge.svg
        :target: https://coveralls.io/github/jakirkham/cyminmax
        :alt: Coveralls

.. image:: https://img.shields.io/github/license/jakirkham/cyminmax.svg
        :target: ./LICENSE.txt
        :alt: License


A minmax implementation in Cython for use with NumPy


* Free software: BSD 3-Clause
* Documentation: https://cyminmax.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `dask-image/dask-image-cookiecutter`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`dask-image/dask-image-cookiecutter`: https://github.com/dask-image/dask-image-cookiecutter

